package com.sohu.paysdkdemo;

import java.util.UUID;

import android.annotation.TargetApi;
import android.content.Intent;
import android.os.Build;
import android.os.Bundle;
import android.util.Log;
import android.view.KeyEvent;
import android.view.View;
import android.widget.TextView;
import android.widget.Toast;

import com.sohu.game.pay.ISDKAccountChangeListener;
import com.sohu.game.pay.ISDKExitResult;
import com.sohu.game.pay.ISDKMethodResult;
import com.sohu.game.pay.ISDKPayResult;
import com.sohu.game.pay.SohuGameSDK;
import com.sohu.game.pay.SohuPaymentOrder;

public class GameActivity extends BaseActivity {


    private boolean isExit = false;

    private final int PAY_AMOUNT = 1;
    private TextView mAccountView;
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        setContentView(R.layout.activity_game);
        mAccountView = (TextView) findViewById(R.id.account);
        setAccount(SohuGameSDK.getLoginUid());
        findViewById(R.id.recharge).setOnClickListener(new View.OnClickListener() {

            @Override
            public void onClick(View v) {
            	
            	String cpOrderId = UUID.randomUUID().toString();
            	SohuPaymentOrder order = new SohuPaymentOrder(
        			PAY_AMOUNT, 	  // 支付金额（分）
        			"新手礼包-998钻石",  // 商品名称
        			"1",			  // 商品ID
        			cpOrderId			// 穿透参数，CP自己的订单ID，用于后续通讯使用
            	);
                SohuGameSDK.pay(GameActivity.this, order, new ISDKMethodResult.Listener<ISDKPayResult>() {
                    @Override
                    public void onResult(ISDKPayResult result) {
                        if (result.assertReturnCode(ISDKPayResult.RET_CODE.SUCCESS)) {
                            Toast.makeText(GameActivity.this, "支付成功", Toast.LENGTH_SHORT).show();
                        } else if (result.assertReturnCode(ISDKPayResult.RET_CODE.ORDER_FAIL)) {
                            Toast.makeText(GameActivity.this, "订单号获得失败", Toast.LENGTH_SHORT).show();
                        } else if (result.assertReturnCode(ISDKPayResult.RET_CODE.FAIL)) {
                            Toast.makeText(GameActivity.this, "支付失败", Toast.LENGTH_SHORT).show();
                        } else if (result.assertReturnCode(ISDKPayResult.RET_CODE.CANCEL)) {
                            Toast.makeText(GameActivity.this, "取消支付", Toast.LENGTH_SHORT).show();
                        }
                    }
                });
            }
        });

        SohuGameSDK.setAccountChangeListener(new ISDKAccountChangeListener() {
            @TargetApi(Build.VERSION_CODES.HONEYCOMB) 
            @Override
            public void onAccountChangeListener(RET_CODE code) {
                if(RET_CODE.SUCCESS.equals(code)){
                	Log.d("MainActivity", "Success");
                    //切换账号成功  此时为新账号登录状态
                	setAccount(SohuGameSDK.getLoginUid());
                }else if(RET_CODE.FAIL.equals(code)){
                	Log.d("MainActivity", "Fail");
                    // 切换账号失败 此时为注销状态
                }else if (RET_CODE.CANCEL.equals(code)){
                	Log.d("MainActivity", "Cancel");
                    //取消切换  此时为前一个账号登录状态 或者 注销状态
                	Intent i = new Intent(GameActivity.this, LoginActivity.class);
                	i.addFlags(Intent.FLAG_ACTIVITY_CLEAR_TASK | Intent.FLAG_ACTIVITY_NEW_TASK);
		            startActivity(i);
		            finish();
                }
            }
        });

    }

    @Override
    public boolean onKeyDown(int keyCode, KeyEvent event) {

        if (keyCode == KeyEvent.KEYCODE_BACK) {
            if(SohuGameSDK.exit(GameActivity.this, new ISDKMethodResult.Listener<ISDKExitResult>() {
                @Override
                public void onResult(ISDKExitResult result) {
                    isExit = result.getReturnCode().equals(ISDKExitResult.RET_CODE.SUCCESS);
                    if (isExit) {
                    	finish();
                    }
                }
            })){
                finish();
            }
            return false;
        }

        return super.onKeyDown(keyCode, event);
    }
    
    @Override
    public void onBackPressed() {
    	moveTaskToBack(false);
        super.onBackPressed();
    }
    
    private void setAccount(String account) {
    	mAccountView.setText("当前登陆账号ID："+account);
    }
    
    @Override
    protected void onDestroy() {
    	SohuGameSDK.destory(this);
        super.onDestroy();
    }

}
